@@ -67,7 +67,7 @@ setMethod("simulate",signature(object="mix"),
 		# random generation is slow when done separately for each t, so first draw
 		# variates for all t, and then determine state sequences iteratively
 		states <- array(,dim=c(nt,nsim))
-		states[bt,] <- simulate(object@prior,n=nsim,is.prior=T)
+		states[bt,] <- simulate(object@prior,nsim=nsim,is.prior=TRUE)
 		sims <- array(,dim=c(nt,ns,nsim))
 				
 		states <- as.vector(states)
@@ -82,7 +82,8 @@ setMethod("simulate",signature(object="mix"),
 		}
 		
 		# generate new mix.sim object
-		class(object) <- c("mix.sim")
+		
+		object <- as(object,"mix.sim") # class(object) <- "depmix.fitted"
 		object@states <- as.matrix(states)
 		
 		object@prior@x <- as.matrix(apply(object@prior@x,2,rep,nsim))
@@ -222,7 +223,7 @@ setMethod("simulate",signature(object="depmix"),
 		# random generation is slow when done separately for each t, so first draw
 		#   variates for all t, and then determine state sequences iteratively
 		states <- array(,dim=c(nt,nsim))
-		states[bt,] <- simulate(object@prior,n=nsim,is.prior=T)
+		states[bt,] <- simulate(object@prior,nsim=nsim,is.prior=TRUE)
 		sims <- array(,dim=c(nt,ns,nsim))
 		for(i in 1:ns) {
 			if(is.stationary(object)) {
@@ -251,7 +252,7 @@ setMethod("simulate",signature(object="depmix"),
 		}
 		
 		# generate new depmix.sim object
-		class(object) <- c("depmix.sim")
+		object <- as(object,"depmix.sim") 
 		object@states <- as.matrix(states)
 		
 		object@prior@x <- as.matrix(apply(object@prior@x,2,rep,nsim))
