@@ -141,8 +141,8 @@ setMethod("fit",
 					...
 				)
 				
-				if(class(object)=="depmix") class(object) <- "depmix.fitted"
-				if(class(object)=="mix") class(object) <- "mix.fitted"
+				if(class(object)=="depmix") object <- as(object,"depmix.fitted") #class(object) <- "depmix.fitted"
+				if(class(object)=="mix") object <- as(object,"mix.fitted") # class(object) <- "mix.fitted"
 				
 				# convergence info
 				object@message <- result$message
@@ -180,6 +180,10 @@ setMethod("fit",
 					linineq <- lincon[ineq, ,drop=FALSE]
 					ineqLB <- lin.l[ineq]
 					ineqUB <- lin.u[ineq]
+					ineqfun <- function(pp) {
+						ans = as.vector(linineq%*%pp)
+						ans
+					}
 				} else {
 					ineqfun = NULL
 					ineqLB=NULL
@@ -200,8 +204,8 @@ setMethod("fit",
 					...
 				)
 				
-				if(class(object)=="depmix") class(object) <- "depmix.fitted"
-				if(class(object)=="mix") class(object) <- "mix.fitted"
+				if(class(object)=="depmix") object <- as(object,"depmix.fitted") # class(object) <- "depmix.fitted"
+				if(class(object)=="mix") object <- as(object,"mix.fitted") # class(object) <- "mix.fitted"
 				
 				object@message <- c(res$convergence," (0 is good in Rsolnp, check manual for other values)")
 				
