@@ -1,7 +1,30 @@
-# depends on getpars(object)
+# depends on getpars(object) & getdf
 setMethod("freepars","mix",
 	function(object) {
-		free <- sum(!getpars(object,which="fixed"))
+		free <- getdf(object@prior)
+		ns <- nstates(object)
+		nresp <- nresp(object)
+		for(i in 1:ns) {
+			for(j in 1: nresp) {
+				free <- free + getdf(object@response[[i]][[j]])
+			}
+		}		
+		free
+	}
+)
+
+# depends on getpars(object) & getdf
+setMethod("freepars","depmix",
+	function(object) {
+		free <- getdf(object@prior)
+		ns <- nstates(object)
+		nresp <- nresp(object)
+		for(i in 1:ns) {
+			free <- free + getdf(object@transition[[i]])
+			for(j in 1: nresp) {
+				free <- free + getdf(object@response[[i]][[j]])
+			}
+		}
 		free
 	}
 )
